@@ -6,10 +6,11 @@
 #include <locale.h>
 #include <pthread.h>
 #include <semaphore.h>
+#include <sys/param.h>
 #include <sys/types.h>
 #if defined(__linux__) || defined(__gnu_hurd__)
-#include <sys/sysinfo.h>
 #include <sys/utsname.h>
+#include <sys/sysinfo.h>
 #elif !defined(__MINGW64__)
 #include <sys/sysctl.h>
 #include <sys/utsname.h>
@@ -354,7 +355,18 @@ xnu_ncneofetch(fetched_info* fi){
     .logofile = "/System/Library/PrivateFrameworks/LoginUIKit.framework/Versions/A/Frameworks/LoginUICore.framework/Versions/A/Resources/apple@2x.png",
   };
   fi->neologo = get_neofetch_art("Darwin");
-  fi->distro_pretty = strdup("OS X 11.4 (Big Sur)"); // FIXME
+  #ifdef __APPLE__
+  #define PREFIX "macOS "
+  char osver[30] = PREFIX; // shrug
+  size_t oldlenp = sizeof(osver) - strlen(PREFIX);
+  if(sysctlbyname("kern.osproductversion", osver + strlen(PREFIX),
+                  &oldlenp, NULL, 0) == 0){
+    fi->distro_pretty = strdup(osver);
+  }
+  #undef PREFIX
+  #else
+  fi->distro_pretty = strdup("macOS");
+  #endif
   return &fbsd;
 }
 
@@ -426,7 +438,7 @@ infoplane_notcurses(struct notcurses* nc, const fetched_info* fi, int planeheigh
     ncplane_printf_aligned(infop, 1, NCALIGN_RIGHT, "%s ", fi->distro_pretty);
   }
   ncplane_set_styles(infop, NCSTYLE_BOLD);
-#ifdef __linux__
+#if defined(__linux__)
   struct sysinfo sinfo;
   sysinfo(&sinfo);
   char totalmet[BPREFIXSTRLEN + 1], usedmet[BPREFIXSTRLEN + 1];
@@ -434,9 +446,17 @@ infoplane_notcurses(struct notcurses* nc, const fetched_info* fi, int planeheigh
   bprefix(sinfo.totalram - sinfo.freeram, 1, usedmet, 1);
   ncplane_printf_aligned(infop, 2, NCALIGN_RIGHT, "Processes: %hu ", sinfo.procs);
   ncplane_printf_aligned(infop, 2, NCALIGN_LEFT, " RAM: %sB/%sB", usedmet, totalmet);
+#elif defined(BSD)
+  uint64_t ram;
+  size_t oldlenp = sizeof(ram);
+  if(sysctlbyname("hw.memsize", &ram, &oldlenp, NULL, 0) == 0){
+    char tram[BPREFIXSTRLEN + 1];
+    bprefix(ram, 1, tram, 1);
+    ncplane_printf_aligned(infop, 2, NCALIGN_LEFT, " RAM: %sB", tram);
+  }
 #endif
-  ncplane_printf_aligned(infop, 3, NCALIGN_LEFT, " DM: %s", fi->desktop);
-  ncplane_printf_aligned(infop, 3, NCALIGN_RIGHT, "Shell: %s ", fi->shell);
+  ncplane_printf_aligned(infop, 3, NCALIGN_LEFT, " DM: %s", fi->desktop ? fi->desktop : "n/a");
+  ncplane_printf_aligned(infop, 3, NCALIGN_RIGHT, "Shell: %s ", fi->shell ? fi->shell : "n/a");
   if(notcurses_cantruecolor(nc)){
     ncplane_printf_aligned(infop, 4, NCALIGN_LEFT, " RGB TERM: %s", fi->term);
     nccell c = CELL_CHAR_INITIALIZER('R');
