@@ -205,11 +205,20 @@ void Ticker(ncpp::NotCurses* nc) {
 int input_demo(ncpp::NotCurses* nc) {
   constexpr auto PLOTHEIGHT = 6;
   auto n = nc->get_stdplane(&dimy, &dimx);
+  // FIXME no ncpp wrapper for Plane::pixelgeom?
+  int celldimx, maxbmapx;
+  ncplane_pixelgeom(*n, nullptr, nullptr, nullptr, &celldimx, nullptr, &maxbmapx);
+  int cols;
+  if(maxbmapx == 0 || celldimx == 0){
+    cols = dimx;
+  }else{
+    cols = maxbmapx / celldimx;
+  }
   struct ncplane_options nopts = {
     .y = dimy - PLOTHEIGHT - 1,
     .x = 0,
     .rows = PLOTHEIGHT,
-    .cols = dimx,
+    .cols = cols,
     .userptr = nullptr,
     .name = "plot",
     .resizecb = nullptr, // FIXME
@@ -331,12 +340,30 @@ int input_demo(ncpp::NotCurses* nc) {
   return 0;
 }
 
-int main(void){
+static void
+usage(const char* arg0, FILE* fp){
+  fprintf(fp, "usage: %s [ -v ]\n", arg0);
+  if(fp == stderr){
+    exit(EXIT_FAILURE);
+  }
+  exit(EXIT_SUCCESS);
+}
+
+int main(int argc, char** argv){
   if(setlocale(LC_ALL, "") == nullptr){
     return EXIT_FAILURE;
   }
   notcurses_options nopts{};
   nopts.loglevel = NCLOGLEVEL_ERROR;
+  if(argc > 2){
+    usage(argv[0], stderr);
+  }else if(argc == 2){
+    if(strcmp(argv[1], "-v") == 0){
+      nopts.loglevel = NCLOGLEVEL_TRACE;
+    }else{
+      usage(argv[0], stderr);
+    }
+  }
   nopts.flags = NCOPTION_INHIBIT_SETLOCALE;
   NotCurses nc(nopts);
   nc.mouse_enable(); // might fail if no mouse is available
