@@ -551,6 +551,7 @@ handle_queued_input(ncinputlayer* nc, ncinput* ni,
     if(nc->inputbuf_occupied == 0){
       return -1;
     }
+    memset(ni, 0, sizeof(*ni));
     int r = pop_input_keypress(nc);
     ret = handle_getc(nc, r, ni, leftmargin, topmargin);
     if(ret != (uint32_t)-1){
@@ -560,10 +561,10 @@ handle_queued_input(ncinputlayer* nc, ncinput* ni,
       enqueue_cursor_report(nc, ni);
     }else if(ni->ctrl && !ni->shift && !ni->alt){
 #ifndef __MINGW64__
-      if(ret == 'c'){
+      if(ret == 'C'){
         raise(SIGINT); // FIXME only if linesigs aren't disabled
         continue;
-      }else if(ret == 'z'){
+      }else if(ret == 'Z'){
         raise(SIGTSTP); // FIXME only if linesigs aren't disabled
         continue;
       }else if(ret == '\\'){
@@ -743,6 +744,9 @@ prep_kitty_special_keys(ncinputlayer* nc){
     { .esc = "\x1b[Q", .key = NCKEY_F02, },
     { .esc = "\x1b[R", .key = NCKEY_F03, },
     { .esc = "\x1b[S", .key = NCKEY_F04, },
+    { .esc = "\x1b[127;2u", .key = NCKEY_BACKSPACE, .shift = 1, },
+    { .esc = "\x1b[127;3u", .key = NCKEY_BACKSPACE, .alt = 1, },
+    { .esc = "\x1b[127;5u", .key = NCKEY_BACKSPACE, .ctrl = 1, },
     { .esc = NULL, .key = NCKEY_INVALID, },
   }, *k;
   for(k = keys ; k->esc ; ++k){
