@@ -92,24 +92,6 @@ notcurses_stop_minimal(void* vnc){
   }
   ret |= mouse_disable(&nc->tcache, f);
   ret |= reset_term_attributes(&nc->tcache, f);
-  if(nc->tcache.kittykbd){
-    if(fbuf_emit(f, "\x1b[<u")){
-      ret = -1;
-    }
-  }
-  if(nc->tcache.ttyfd >= 0){
-    if(nc->tcache.tpreserved){
-      ret |= tcsetattr(nc->tcache.ttyfd, TCSAFLUSH, nc->tcache.tpreserved);
-    }
-    if((esc = get_escape(&nc->tcache, ESCAPE_RMCUP))){
-      if(sprite_clear_all(&nc->tcache, f)){
-        ret = -1;
-      }
-      if(fbuf_emit(f, esc)){
-        ret = -1;
-      }
-    }
-  }
   if((esc = get_escape(&nc->tcache, ESCAPE_RMKX)) && fbuf_emit(f, esc)){
     ret = -1;
   }
@@ -120,6 +102,25 @@ notcurses_stop_minimal(void* vnc){
   if(blocking_write(fileno(nc->ttyfp), f->buf, f->used)){
     ret = -1;
   }
+  fbuf_reset(f);
+  if(nc->tcache.ttyfd >= 0){
+    if(nc->tcache.tpreserved){
+      ret |= tcsetattr(nc->tcache.ttyfd, TCSAFLUSH, nc->tcache.tpreserved);
+    }
+    if(nc->tcache.kittykbd){
+      if(tty_emit("\x1b[<u", nc->tcache.ttyfd)){
+        ret = -1;
+      }
+    }
+    if((esc = get_escape(&nc->tcache, ESCAPE_RMCUP))){
+      if(sprite_clear_all(&nc->tcache, f)){ // send this to f
+        ret = -1;
+      }
+      if(tty_emit(esc, nc->tcache.ttyfd)){ // but this goes to ttyfd
+        ret = -1;
+      }
+    }
+  }
   return ret;
 }
 
@@ -983,11 +984,8 @@ recursive_lock_init(pthread_mutex_t *lock){
 #endif
 }
 
-int notcurses_check_pixel_support(const notcurses* nc){
-  if(nc->tcache.pixel_draw || nc->tcache.pixel_draw_late){
-    return 1;
-  }
-  return 0;
+ncpixelimpl_e notcurses_check_pixel_support(const notcurses* nc){
+  return nc->tcache.pixel_implementation;
 }
 
 // FIXME cut this up into a few distinct pieces, yearrrgh
@@ -1269,6 +1267,7 @@ int notcurses_stop(notcurses* nc){
 #endif
     ret |= pthread_mutex_destroy(&nc->stats.lock);
     ret |= pthread_mutex_destroy(&nc->pilelock);
+    fbuf_free(&nc->rstate.f);
     free_terminfo_cache(&nc->tcache);
     free(nc);
   }
@@ -3037,17 +3036,29 @@ int notcurses_ucs32_to_utf8(const uint32_t* ucs32, unsigned ucs32count,
 }
 
 int ncstrwidth(const char* mbs){
-  int cols = 0;   // number of columns consumed thus far
+  return ncstrwidth_valid(mbs, NULL, NULL);
+}
+
+int ncstrwidth_valid(const char* egcs, int* validbytes, int* validwidth){
+  int cols = 0;  // number of columns consumed thus far
+  if(validwidth == NULL){
+    validwidth = &cols;
+  }
+  int bytes = 0; // number of bytes consumed thus far
+  if(validbytes == NULL){
+    validbytes = &bytes;
+  }
   do{
     int thesecols, thesebytes;
-    thesebytes = utf8_egc_len(mbs, &thesecols);
+    thesebytes = utf8_egc_len(egcs, &thesecols);
     if(thesebytes < 0){
       return -1;
     }
-    mbs += thesebytes;
-    cols += thesecols;
-  }while(*mbs);
-  return cols;
+    egcs += thesebytes;
+    *validbytes += thesebytes;
+    *validwidth += thesecols;
+  }while(*egcs);
+  return *validwidth;
 }
 
 void ncplane_pixelgeom(const ncplane* n, int* RESTRICT pxy, int* RESTRICT pxx,
