@@ -189,6 +189,7 @@ paint_sprixel(ncplane* p, struct crender* rvec, int starty, int startx,
 // the sprixelstack orders sprixels of the plane (so we needn't keep them
 // ordered between renders). each time we meet a sprixel, extract it from
 // the pile's sprixel list, and update the sprixelstack.
+__attribute__ ((nonnull (1, 2, 7)))
 static void
 paint(ncplane* p, struct crender* rvec, int dstleny, int dstlenx,
       int dstabsy, int dstabsx, sprixel** sprixelstack){
@@ -516,8 +517,11 @@ int ncplane_mergedown(ncplane* restrict src, ncplane* restrict dst,
     return -1;
   }
   init_rvec(rvec, totalcells);
-  paint(src, rvec, dst->leny, dst->lenx, dst->absy, dst->absx, NULL);
-  paint(dst, rvec, dst->leny, dst->lenx, dst->absy, dst->absx, NULL);
+  sprixel* s = NULL;
+  paint(src, rvec, dst->leny, dst->lenx, dst->absy, dst->absx, &s);
+  assert(NULL == s);
+  paint(dst, rvec, dst->leny, dst->lenx, dst->absy, dst->absx, &s);
+  assert(NULL == s);
 //fprintf(stderr, "Postpaint start (%dx%d)\n", dst->leny, dst->lenx);
   const struct tinfo* ti = &ncplane_notcurses_const(dst)->tcache;
   postpaint(ti, rendfb, dst->leny, dst->lenx, rvec, &dst->pool);
@@ -819,7 +823,8 @@ clean_sprixels(notcurses* nc, ncpile* p, fbuf* f, int scrolls){
   sprixel** parent = &p->sprixelcache;
   int64_t bytesemitted = 0;
   while( (s = *parent) ){
-    loginfo("Phase 1 sprixel %u state %d\n", s->id, s->invalidated);
+    loginfo("Phase 1 sprixel %u state %d loc %d/%d\n", s->id,
+            s->invalidated, s->n ? s->n->absy : -1, s->n ? s->n->absx : -1);
     if(s->invalidated == SPRIXEL_QUIESCENT){
       if(p != nc->last_pile){
         s->invalidated = SPRIXEL_UNSEEN;
