@@ -241,6 +241,14 @@ int sixel_wipe(sprixel* s, int ycell, int xcell){
   change_p2(s->glyph.buf, SIXEL_P2_TRANS);
   assert(NULL == s->n->tam[s->dimx * ycell + xcell].auxvector);
   s->n->tam[s->dimx * ycell + xcell].auxvector = auxvec;
+  // FIXME this invalidation ought not be necessary, since we're simply
+  // wiping, and thus a glyph is going to be printed over whatever we've
+  // just destroyed. in alacritty, however, this isn't sufficient to knock
+  // out a graphic; we need repaint with the transparency.
+  // see https://github.com/dankamongmen/notcurses/issues/2142
+  int absx, absy;
+  ncplane_abs_yx(s->n, &absy, &absx);
+  sprixel_invalidate(s, absy, absx);
   return 0;
 }
 
@@ -352,7 +360,46 @@ update_deets(uint32_t rgb, cdetails* deets){
   ++deets->count;
 }
 
-// no matter the input palette, we can always get a maximum of 64 colors if we
+// goes through the needs_refresh matrix, and damages cells needing refreshing.
+void sixel_refresh(const ncpile* p, sprixel* s){
+  if(s->needs_refresh == NULL){
+    return;
+  }
+  int absy, absx;
+  ncplane_abs_yx(s->n, &absy, &absx);
+  for(int y = 0 ; y < s->dimy ; ++y){
+    const int yy = absy + y;
+    for(int x = 0 ; x < s->dimx ; ++x){
+      int idx = y * s->dimx + x;
+      if(s->needs_refresh[idx]){
+        const int xx = absx + x;
+        int ridx = yy * p->dimx + xx;
+        struct crender *r = &p->crender[ridx];
+        r->s.damaged = 1;
+      }
+    }
+  }
+  free(s->needs_refresh);
+  s->needs_refresh = NULL;
+}
+
+// when we first cross into a new cell, we check its old state, and if it
+// was transparent, set the rmatrix low. otherwise, set it high. this should
+// only be called for the first pixel in each cell.
+static inline void
+update_rmatrix(unsigned char* rmatrix, int txyidx, const tament* tam){
+  if(rmatrix == NULL){
+    return;
+  }
+  sprixcell_e state = tam[txyidx].state;
+  if(state == SPRIXCELL_TRANSPARENT || state > SPRIXCELL_ANNIHILATED){
+    rmatrix[txyidx] = 0;
+  }else{
+    rmatrix[txyidx] = 1;
+  }
+}
+
+// no mattter the input palette, we can always get a maximum of 64 colors if we
 // mask at 0xc0 on each component (this partitions each component into 4 chunks,
 // and 4 * 4 * 4 -> 64). so this will never overflow our color register table
 // (assumed to have at least 256 registers). at each color, we store a pixel
@@ -369,25 +416,31 @@ extract_color_table(const uint32_t* data, int linesize, int cols,
   const int cdimx = s->cellpxx;
   unsigned char mask = 0xc0;
   int pos = 0; // pixel position
+  unsigned char* rmatrix = bargs->u.pixel.spx->needs_refresh;
   for(int visy = begy ; visy < (begy + leny) ; visy += 6){ // pixel row
     for(int visx = begx ; visx < (begx + lenx) ; visx += 1){ // pixel column
       for(int sy = visy ; sy < (begy + leny) && sy < visy + 6 ; ++sy){ // offset within sprixel
         const uint32_t* rgb = (data + (linesize / 4 * sy) + visx);
         int txyidx = (sy / cdimy) * cols + (visx / cdimx);
+        // we can't just check if lastidx != txyidx; that's true for each row
+        // of the cell. this will only be true once.
+        bool firstpix = (sy % cdimy == 0 && visx % cdimx == 0);
+        bool lastrow = visy + 6 >= begy + leny;
         // we do *not* exempt already-wiped pixels from palette creation. once
         // we're done, we'll call sixel_wipe() on these cells. so they remain
         // one of SPRIXCELL_ANNIHILATED or SPRIXCELL_ANNIHILATED_TRANS.
         if(tam[txyidx].state != SPRIXCELL_ANNIHILATED && tam[txyidx].state != SPRIXCELL_ANNIHILATED_TRANS){
           if(rgba_trans_p(*rgb, bargs->transcolor)){
-            if(sy % cdimy == 0 && visx % cdimx == 0){
+            if(firstpix){
+              update_rmatrix(rmatrix, txyidx, tam);
               tam[txyidx].state = SPRIXCELL_TRANSPARENT;
             }else if(tam[txyidx].state == SPRIXCELL_OPAQUE_SIXEL){
               tam[txyidx].state = SPRIXCELL_MIXED_SIXEL;
             }
             stab->p2 = SIXEL_P2_TRANS; // even one forces P2=1
-            continue;
           }else{
-            if(sy % cdimy == 0 && visx % cdimx == 0){
+            if(firstpix){
+              update_rmatrix(rmatrix, txyidx, tam);
               tam[txyidx].state = SPRIXCELL_OPAQUE_SIXEL;
             }else if(tam[txyidx].state == SPRIXCELL_TRANSPARENT){
               tam[txyidx].state = SPRIXCELL_MIXED_SIXEL;
@@ -396,18 +449,35 @@ extract_color_table(const uint32_t* data, int linesize, int cols,
         }else{
 //fprintf(stderr, "TRANS SKIP %d %d %d %d (cell: %d %d)\n", visy, visx, sy, txyidx, sy / cdimy, visx / cdimx);
           if(rgba_trans_p(*rgb, bargs->transcolor)){
-            if(sy % cdimy == 0 && visx % cdimx == 0){
+            if(firstpix){
+              update_rmatrix(rmatrix, txyidx, tam);
               tam[txyidx].state = SPRIXCELL_ANNIHILATED_TRANS;
               free(tam[txyidx].auxvector);
               tam[txyidx].auxvector = NULL;
             }
           }else{
-            tam[txyidx].state = SPRIXCELL_ANNIHILATED;
-            if(sy % cdimy == 0 && visx % cdimx == 0){
+            if(firstpix){
+              update_rmatrix(rmatrix, txyidx, tam);
               free(tam[txyidx].auxvector);
               tam[txyidx].auxvector = NULL;
             }
+            tam[txyidx].state = SPRIXCELL_ANNIHILATED;
           }
+          stab->p2 = SIXEL_P2_TRANS; // even one forces P2=1
+        }
+        if(lastrow){
+          bool lastcol = visx + 1 >= begx + lenx;
+          if(lastcol){
+            // if we're opaque, we needn't clear the old cell with a glyph
+            if(tam[txyidx].state == SPRIXCELL_OPAQUE_SIXEL){
+              if(rmatrix){
+                rmatrix[txyidx] = 0;
+              }
+            }
+          }
+        }
+        if(rgba_trans_p(*rgb, bargs->transcolor)){
+          continue;
         }
         unsigned char comps[RGBSIZE];
         break_sixel_comps(comps, *rgb, mask);
@@ -807,7 +877,7 @@ sixel_blit_inner(int leny, int lenx, sixeltable* stab, sprixel* s, tament* tam){
   }
   scrub_tam_boundaries(tam, outy, lenx, s->cellpxy, s->cellpxx);
   // take ownership of buf on success
-  if(plane_blit_sixel(s, &f, outy, lenx, parse_start, tam) < 0){
+  if(plane_blit_sixel(s, &f, outy, lenx, parse_start, tam, SPRIXEL_INVALIDATED) < 0){
     fbuf_free(&f);
     return -1;
   }
@@ -859,11 +929,21 @@ int sixel_blit(ncplane* n, int linesize, const void* data, int leny, int lenx,
       return -1;
     }
     memset(tam, 0, sizeof(*tam) * rows * cols);
+  }else{
+    typeof(bargs->u.pixel.spx->needs_refresh) rmatrix;
+    rmatrix = malloc(sizeof(*rmatrix) * rows * cols);
+    if(rmatrix == NULL){
+      sixelmap_free(stable.map);
+      free(stable.deets);
+      return -1;
+    }
+    bargs->u.pixel.spx->needs_refresh = rmatrix;
   }
   if(extract_color_table(data, linesize, cols, leny, lenx, &stable, tam, bargs)){
     if(!reuse){
       free(tam);
     }
+    free(bargs->u.pixel.spx->needs_refresh);
     sixelmap_free(stable.map);
     free(stable.deets);
     return -1;
